@@ -66,12 +66,12 @@ class RiskAssignment(WebhooksMixin, ChangeLoggedModel):
         fk_field='object_id'
     )
     risk = models.ForeignKey(
-        to='risks.Risk',
+        to='users_and_computers.Risk',
         on_delete=models.PROTECT,
         related_name='risk_assignments'
     )
     relation = models.ForeignKey(
-        to='risks.RiskRelation',
+        to='users_and_computers.RiskRelation',
         on_delete=models.PROTECT,
         related_name='risk_assignments'
     )
